@@ -12,9 +12,9 @@ def __if_number_get_string(number):
 
 def get_unicode(strOrUnicode, encoding='utf-8'):
     strOrUnicode = __if_number_get_string(strOrUnicode)
-    if isinstance(strOrUnicode, str):
+    if isinstance(strOrUnicode, unicode):
         return strOrUnicode
-    return str(strOrUnicode, encoding, errors='ignore')
+    return unicode(strOrUnicode, encoding, errors='ignore')
 
 
 def get_string(strOrUnicode, encoding='utf-8'):
@@ -22,6 +22,6 @@ def get_string(strOrUnicode, encoding='utf-8'):
     if sys.version_info >= (3,):
         return strOrUnicode
 
-    if isinstance(strOrUnicode, str):
+    if isinstance(strOrUnicode, unicode):
         return strOrUnicode.encode(encoding)
     return strOrUnicode
